@@ -7,18 +7,23 @@ licence: https://opensource.org/licenses/MIT
 
 import os
 import logging
+from pathlib import Path
 
 from ..binary import bytes_to_bits
 from ..storage import loaders, savers
-from ..streams import FileFormatError
+from ..magic import FileFormatError, Regex
 from ..font import Font, Coord
 from ..glyph import Glyph
 from ..struct import flag, bitfield, big_endian as be
 from ..properties import Props
 
 
-@loaders.register('font', magic=(b'\x0f\0', b'\x0f\2'), name='amiga-fc')
-def load_amiga_fc(f, where):
+@loaders.register(
+    name='amiga-fc',
+    magic=(b'\x0f\0', b'\x0f\2'),
+    patterns=('*.font',),
+)
+def load_amiga_fc(f):
     """Load font from Amiga disk font contents (.FONT) file."""
     fch = _FONT_CONTENTS_HEADER.read_from(f)
     if fch.fch_FileID == _FCH_ID:
@@ -48,21 +53,31 @@ def load_amiga_fc(f, where):
             tags = _TAG_ITEM.array(fc.tfc_TagCount).from_bytes(fc.tfc_FileName[tag_start:])
         else:
             tags = ()
-        # amiga fs is case insensitive, so we need to loop over listdir and match
-        for filename in where:
-            if filename.lower() == name.lower():
-                with where.open(filename, 'r') as stream:
-                    pack.append(_load_amiga(stream, where, tags))
+        # amiga fs is case insensitive; need to loop over listdir and match
+        # font files given relative to local directory
+        local_dir = Path(f.name).parent
+        for filename in f.where.iter_sub(local_dir):
+            if Path(filename.lower()).relative_to(local_dir) == Path(name.lower()):
+                logging.debug('Reading font file %s on %r', filename, f.where)
+                with f.where.open(filename, 'r') as stream:
+                    pack.append(_load_amiga(stream, tags))
+            else:
+                logging.debug('Skipping file %s', filename)
     return pack
 
 
-@loaders.register('amiga', magic=(b'\0\0\x03\xf3',), name='amiga')
-def load_amiga(f, where=None, tags=()):
+@loaders.register(
+    name='amiga',
+    magic=(b'\0\0\x03\xf3',),
+    # digits-only filename
+    patterns=(Regex(r'\d+'),),
+)
+def load_amiga(instream, tags=()):
     """Load font from Amiga disk font file."""
-    return _load_amiga(f, where, tags)
+    return _load_amiga(instream, tags)
 
 @savers.register(linked=load_amiga)
-def save_amiga(pack, outstream, where=None):
+def save_amiga(pack, outstream):
     raise FileFormatError('Saving to Amiga disk font file not supported.')
 
 
@@ -229,7 +244,7 @@ _TAG_ITEM = be.Struct(
 # read Amiga font
 
 
-def _load_amiga(f, where, tags):
+def _load_amiga(f, tags):
     """Load font from Amiga disk font file."""
     # read & ignore header
     _read_header(f)
