@@ -19,7 +19,7 @@ except ImportError:
 from ..basetypes import Coord
 from ..encoding import charmaps
 from .. import streams
-from ..streams import FileFormatError
+from ..magic import FileFormatError
 from ..binary import int_to_bytes, bytes_to_int
 from ..struct import little_endian as le
 from ..properties import reverse_dict
@@ -31,27 +31,37 @@ from ..labels import Codepoint, Char
 from .windows import CHARSET_MAP, CHARSET_REVERSE_MAP
 
 
-##############################################################################
-
 # text/xml/binary format: https://www.angelcode.com/products/bmfont/doc/file_format.html
 # json format: https://github.com/Jam3/load-bmfont/blob/master/json-spec.md
 
+_BMF_MAGIC = b'BMF'
+
+
 ##############################################################################
 # top-level calls
 
 if Image:
-    @loaders.register('bmf', name='bmfont')
-    def load_bmfont(infile, where, outline:bool=False):
+    # the magic is optional - only for binary descriptor file
+    @loaders.register(
+        name='bmfont',
+        magic=(
+            _BMF_MAGIC,
+            b'info',
+            b'<?xml version="1.0"?>\n<font>',
+        ),
+        patterns=('*.fnt',),
+    )
+    def load_bmfont(infile, outline:bool=False):
         """
         Load fonts from Angelcode BMFont format.
 
         outline: extract outline layer instead of glyph layer
         """
-        return _read_bmfont(infile, where, outline)
+        return _read_bmfont(infile, outline)
 
     @savers.register(linked=load_bmfont)
     def save(
-            fonts, outfile, where,
+            fonts, outfile,
             image_size:Coord=(256, 256),
             image_format:str='png',
             packed:bool=True,
@@ -67,13 +77,17 @@ if Image:
         """
         if len(fonts) > 1:
             raise FileFormatError("Can only save one font to BMFont file.")
-        _create_bmfont(outfile, where, fonts[0], image_size, packed, image_format, descriptor)
+        _create_bmfont(
+            outfile, fonts[0],
+            image_size, packed, image_format, descriptor
+        )
 
 
 ##############################################################################
 # BMFont spec
 # see http://www.angelcode.com/products/bmfont/doc/file_format.html
 
+
 _HEAD = le.Struct(
     magic='3s',
     version='uint8',
@@ -543,11 +557,12 @@ def _parse_bmfont_props(name, bmformat, imgformats, info, common):
     return properties
 
 
-def _read_bmfont(infile, container, outline):
+def _read_bmfont(infile, outline):
     """Read a bmfont from a container."""
+    container = infile.where
     magic = infile.peek(3)
     fontinfo = {}
-    if magic.startswith(b'BMF'):
+    if magic.startswith(_BMF_MAGIC):
         logging.debug('found binary: %s', infile.name)
         fontinfo = _parse_binary(infile.read())
     else:
@@ -704,10 +719,11 @@ def _create_textdict(name, dict):
     )
 
 def _create_bmfont(
-        outfile, container, font,
+        outfile, font,
         size=(256, 256), packed=False, imageformat='png', descriptor='text'
     ):
     """Create a bmfont package."""
+    container = outfile.where
     path = Path('.') / font.family
     fontname = font.name.replace(' ', '_')
     encoding = font.encoding
@@ -734,7 +750,7 @@ def _create_bmfont(
     # >  file   The texture file name.
     props['pages'] = []
     for page_id, page in enumerate(pages):
-        name = container.unused_name(f'{path}/{fontname}_{page_id}', imageformat)
+        name = container.unused_name(f'{path}/{fontname}_{page_id}.{imageformat}')
         with container.open(name, 'w') as imgfile:
             page.save(imgfile, format=imageformat)
         props['pages'].append({
