@@ -17,7 +17,7 @@ except ImportError:
 from ..basetypes import Coord, RGB
 from ..binary import ceildiv
 from ..storage import loaders, savers
-from ..streams import FileFormatError
+from ..magic import FileFormatError
 from ..font import Font
 from ..glyph import Glyph
 from ..chart import chart, traverse_chart
@@ -38,9 +38,12 @@ DEFAULT_IMAGE_FORMAT = 'png'
 
 if Image:
     @loaders.register(
-        'png', 'bmp', 'gif', 'tif', 'tiff',
-        'ppm', 'pgm', 'pbm', 'pnm', 'webp',
-        'pcx', 'tga', 'jpg', 'jpeg',
+        name='image',
+        patterns=(
+            '*.png', '*.bmp', '*.gif', '*.tif', '*.tiff',
+            '*.ppm', '*.pgm', '*.pbm', '*.pnm', '*.webp',
+            '*.pcx', '*.tga', '*.jpg', '*.jpeg',
+        ),
         magic=(
             # PNG
             b'\x89PNG\r\n\x1a\n',
@@ -59,10 +62,9 @@ if Image:
             # JPEG
             b'\xFF\xD8\xFF',
         ),
-        name='image',
     )
     def load_image(
-            infile, where=None,
+            infile,
             cell:Coord=(8, 8),
             margin:Coord=(0, 0),
             padding:Coord=(0, 0),
@@ -167,7 +169,7 @@ if Image:
 
     @savers.register(linked=load_image)
     def save_image(
-            fonts, outfile, where=None, *,
+            fonts, outfile, *,
             image_format:str='',
             columns:int=32,
             margin:Coord=(0, 0),
