@@ -18,7 +18,7 @@ from types import SimpleNamespace
 from ...binary import bytes_to_bits, ceildiv, align
 from ...struct import little_endian as le
 from ...properties import reverse_dict
-from ...streams import FileFormatError
+from ...magic import FileFormatError
 from ...properties import Props
 from ...font import Font
 from ...glyph import Glyph
@@ -504,8 +504,7 @@ def _convert_vector_glyphs(glyphdata, win_props):
 
 def bytes_to_str(s, encoding='latin-1'):
     """Extract null-terminated string from bytes."""
-    if b'\0' in s:
-        s, _ = s.split(b'\0', 1)
+    s, _, _ = s.partition(b'\0')
     return s.decode(encoding, errors='replace')
 
 def _convert_win_props(data, win_props):
@@ -669,12 +668,14 @@ def create_fnt(font, version=0x200, vector=False):
         # x_width should equal average width
         pix_width = font.raster_size.x
     font = _make_contiguous(font, pix_width)
-    bitmaps, char_table, offset_bitmaps = _convert_to_fnt_glyphs(
+    bitmaps, char_table, offset_bitmaps, byte_width = _convert_to_fnt_glyphs(
         font, version, vector, add_shift_up
     )
     bitmap_size = sum(len(_b) for _b in bitmaps)
     win_props, header_ext, stringtable = _convert_to_fnt_props(
-        font, version, vector, offset_bitmaps, bitmap_size, add_shift_up
+        font, version, vector,
+        offset_bitmaps, bitmap_size, byte_width,
+        add_shift_up
     )
     data = (
         bytes(win_props) + bytes(header_ext)
@@ -686,7 +687,9 @@ def create_fnt(font, version=0x200, vector=False):
 
 
 def _convert_to_fnt_props(
-        font, version, vector, offset_bitmaps, bitmap_size, add_shift_up
+        font, version, vector,
+        offset_bitmaps, bitmap_size, byte_width,
+        add_shift_up
     ):
     """Convert font to FNT headers."""
     # get lowest and highest codepoints (contiguous glyphs followed by blank)
@@ -765,10 +768,8 @@ def _convert_to_fnt_props(
         dfLastChar=max_ord,
         dfDefaultChar=default_ord - min_ord,
         dfBreakChar=break_ord - min_ord,
-        # round up to multiple of 2 bytes to word-align v1.0 strikes
-        # (not used for v2.0+ ?)
-        # +2 as we append the guaranteed-blank glyph
-        dfWidthBytes=ceildiv(font.raster_size.x*(max_ord-min_ord+2), 16)*2,
+        # strike width in bytes. not used for vector. (not used for v2.0+ ?)
+        dfWidthBytes=byte_width,
         dfDevice=device_name_offset,
         dfFace=face_name_offset,
         dfBitsPointer=0, # used on loading
@@ -790,12 +791,14 @@ def _convert_to_fnt_glyphs(font, version, vector, add_shift_up):
         # this should equal the dfAscent value
         win_ascent = font.raster_size.y - add_shift_up
         bitmaps = _convert_vector_glyphs_to_fnt(font.glyphs, win_ascent)
+        byte_width = 0
     elif version == 0x100:
         strike = Raster.concatenate(*(_g.pixels for _g in font.glyphs))
         # spacer to ensure we'll be word-aligned (as_bytes will byte-align)
         spacer = Raster.blank(width=16-(strike.width%16), height=strike.height)
         strike = Raster.concatenate(strike, spacer)
         bitmaps = (strike.as_bytes(),)
+        byte_width = ceildiv(strike.width, 8)
     else:
         # create the bitmaps
         bitmaps = (_glyph.as_bytes() for _glyph in font.glyphs)
@@ -807,20 +810,29 @@ def _convert_to_fnt_glyphs(font, version, vector, add_shift_up):
             )
             for _glyph, _bm in zip(font.glyphs, bitmaps)
         )
-    glyph_offsets = [0] + list(
-        itertools.accumulate(len(_bm) for _bm in bitmaps)
-    )
+        # not sure if this gets used for v2, as it isn't really useful there
+        # using the logic from mkwinfont, max bytewidth aligned to multiple of 2
+        byte_width = ceildiv(max(_g.width for _g in font.glyphs), 8)
+        byte_width = align(byte_width, 1)
+    if version == 0x100 and not vector:
+        glyph_offsets = [0] + list(
+            itertools.accumulate(_g.width for _g in font.glyphs)
+        )
+    else:
+        glyph_offsets = [0] + list(
+            itertools.accumulate(len(_bm) for _bm in bitmaps)
+        )
+    base_offset = _FNT_HEADER.size + _FNT_HEADER_EXT[version].size
     if not vector:
         glyph_entry = _GLYPH_ENTRY[version]
     else:
         glyph_entry = _GLYPH_ENTRY_PVECTOR
-    base_offset = _FNT_HEADER.size + _FNT_HEADER_EXT[version].size
     # vector format and v1 do not include dfBitmapOffset in the table
     glyph_table_size = len(font.glyphs) * glyph_entry.size
-    if version==0x100 and font.spacing == 'character-cell':
+    if version == 0x100 and font.spacing == 'character-cell':
         char_table = (b'',)
         offset_bitmaps = base_offset
-    elif vector or version==0x100:
+    elif vector or version == 0x100:
         char_table = (
             bytes(glyph_entry(
                 geWidth=_glyph.width,
@@ -838,7 +850,7 @@ def _convert_to_fnt_glyphs(font, version, vector, add_shift_up):
             ))
             for _glyph, _glyph_offset in zip(font.glyphs, glyph_offsets)
         )
-    return bitmaps, char_table, offset_bitmaps
+    return bitmaps, char_table, offset_bitmaps, byte_width
 
 
 def _convert_vector_glyphs_to_fnt(glyphs, win_ascent):
